#ifndef _SCHNLSP_H
#define _SCHNLSP_H
#if __GNUC__ >=3
#pragma GCC system_header
#endif


#define SECPKG_ATTR_SUPPORTED_ALGS 86
#define SECPKG_ATTR_CIPHER_STRENGTHS 87
#define SECPKG_ATTR_SUPPORTED_PROTOCOLS 88

#include <schannel.h>

#endif /* _SCHNLSP_H */
