#ifndef _WINRESRC_H
#define _WINRESRC_H
#if __GNUC__ >=3
#pragma GCC system_header
#endif

#define WIN32_LEAN_AND_MEAN
#include <winuser.h>
#include <winnt.h>
#include <winver.h>
#include <dde.h>
#include <dlgs.h>
#include <commctrl.h>
#endif
