/*
http://msdn.microsoft.com/en-us/library/ms836805.aspx

CECONFIG.H contains a list of the environment variables for the components
that were included when a platform was built. This file is automatically
included in the Windows CE image—the familiar NK.BIN—that is created for
a platform.
*/
