#ifndef _EXDISPID_H
#define _EXDISPID_H
#if __GNUC__ >=3
#pragma GCC system_header
#endif

#define DISPID_BEFORENAVIGATE2 250
#define DISPID_NEWWINDOW2 251
#define DISPID_PROGRESSCHANGE 108
#define DISPID_DOCUMENTCOMPLETE 259
#define DISPID_STATUSTEXTCHANGE 102
#define DISPID_TITLECHANGE 113

#endif
