/* Generated automatically. */
static const char configuration_arguments[] = "/home/bruno/devel/cegcc-build/gcc/configure --prefix=/home/bruno/x-tools/arm-mingw32ce --build=x86_64-pc-linux-gnu --with-gcc --with-gnu-ld --with-gnu-as --enable-threads=win32 --disable-nls --enable-languages=c,c++ --disable-win32-registry --disable-multilib --disable-interwork --without-newlib --enable-checking --with-headers --disable-__cxa_atexit --host=x86_64-pc-linux-gnu --target=arm-mingw32ce";
static const char thread_model[] = "win32";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { "cpu", "arm6" } };
