#ifndef _CPLEXT_H
#define _CPLEXT_H
#if __GNUC__ >= 3
#pragma GCC system_header
#endif

#define CPLPAGE_MOUSE_BUTTONS 1
#define CPLPAGE_MOUSE_PTRMOTION 2
#define CPLPAGE_MOUSE_WHEEL 3
#define CPLPAGE_KEYBOARD_SPEED 1
#define CPLPAGE_DISPLAY_BACKGROUND 1
#endif
